package com.stimlsoft;

import java.io.FileNotFoundException;
import java.io.FileOutputStream;

import com.stimulsoft.base.drawing.enums.StiBorderSides;
import com.stimulsoft.base.exception.StiException;
import com.stimulsoft.base.system.geometry.StiRectangle;
import com.stimulsoft.base.system.type.StiSystemTypeEnum;
import com.stimulsoft.report.StiExportManager;
import com.stimulsoft.report.StiReport;
import com.stimulsoft.report.components.StiPage;
import com.stimulsoft.report.components.bands.StiDataBand;
import com.stimulsoft.report.components.simplecomponents.StiText;
import com.stimulsoft.report.dictionary.StiDataColumn;
import com.stimulsoft.report.dictionary.StiDataColumnsCollection;
import com.stimulsoft.report.dictionary.StiDataParameter;
import com.stimulsoft.report.dictionary.StiDataParametersCollection;
import com.stimulsoft.report.dictionary.StiDictionary;
import com.stimulsoft.report.dictionary.dataSources.StiOracleSource;
import com.stimulsoft.report.dictionary.databases.StiOracleDatabase;
import com.stimulsoft.report.dictionary.enums.StiSqlSourceType;

/**
 * Copyright Stimulsoft
 */
public class TestOracle {

    /**
     * @param args
     * @throws StiException
     * @throws FileNotFoundException
     */
    public static void main(String[] args) throws FileNotFoundException, StiException {
        StiReport report = StiReport.newInstance();
        StiPage page = report.getPages().get(0);
        report.setDictionary(new StiDictionary(report));
        StiOracleDatabase db = new StiOracleDatabase("test", "test", "url=jdbc:oracle:thin:@192.168.64.128:1521:orcl;user=sys as sysdba;password=oracle");
        report.getDictionary().getDatabases().add(db);
        StiOracleSource source = new StiOracleSource("test.DataSource", "DataSource", "DataSource", "CALL doublingProc(@Parameter1, @Column1)");
        source.setType(StiSqlSourceType.StoredProcedure);
        source.setDictionary(report.getDictionary());
        report.getDictionary().getDataSources().add(source);
        source.setColumns(new StiDataColumnsCollection());
        source.getColumns().add(new StiDataColumn("Column1", "Column1", "Column1", StiSystemTypeEnum.SystemInt32.getSystemType()));
        source.setParameters(new StiDataParametersCollection());
        StiDataParameter param = new StiDataParameter("Parameter1", 8, 0);
        param.setExpression("1");
        source.getParameters().add(param);

        StiDataBand dataBand = new StiDataBand();
        dataBand.setDataSourceName("DataSource");
        dataBand.setHeight(0.5);
        dataBand.setName("DataBand");
        page.getComponents().add(dataBand);

        StiText dataText = new StiText(new StiRectangle(0, 0, page.getWidth(), 0.5));
        dataText.setText("{DataSource.Column1}");
        dataText.setName("DataText");
        dataText.getBorder().setSide(StiBorderSides.All);
        dataBand.getComponents().add(dataText);
        report.Render();
        StiExportManager.exportPdf(report, new FileOutputStream("c:/0/report.pdf"));

    }

}
